#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cabal-doctest
version:              1.0.8
visibility:           public
id:                   cabal-doctest-1.0.8-C2NU0MzNPJgFFyaSwaSZPn
key:                  cabal-doctest-1.0.8-C2NU0MzNPJgFFyaSwaSZPn
license:              BSD-3-Clause
copyright:            (c) 2017 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/cabal-doctest
synopsis:             A Setup.hs helper for doctests running
description:
    Currently (beginning of 2017), there isn'\''t @cabal doctest@
    command. Yet, to properly work doctest needs plenty of configuration.
    This library provides the common bits for writing custom Setup.hs
    See <https://github.com/haskell/cabal/issues/2327 Cabal/2327> for the progress
    of @cabal doctest@, i.e. whether this library is obsolete.

category:             Distribution
abi:                  76a608b6fb94a186f9d48b1df359fc92
exposed:              True
exposed-modules:      Distribution.Extra.Doctest
import-dirs:          /usr/lib/ghc-8.10.5/site-local/cabal-doctest-1.0.8
library-dirs:         /usr/lib/ghc-8.10.5/site-local/cabal-doctest-1.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/cabal-doctest-1.0.8
hs-libraries:         HScabal-doctest-1.0.8-C2NU0MzNPJgFFyaSwaSZPn
depends:
    Cabal-3.2.1.0 base-4.14.2.0 directory-1.3.6.0 filepath-1.4.2.1

haddock-interfaces:
    /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock

haddock-html:         /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

